@@ -8,7 +8,13 @@ from pydantic import BaseModel
 
 from fastapi_cloud_cli.config import Settings
 from fastapi_cloud_cli.utils.api import APIClient
-from fastapi_cloud_cli.utils.auth import AuthConfig, write_auth_config
+from fastapi_cloud_cli.utils.auth import (
+    AuthConfig,
+    get_auth_token,
+    is_logged_in,
+    is_token_expired,
+    write_auth_config,
+)
 from fastapi_cloud_cli.utils.cli import get_rich_toolkit, handle_http_errors
 
 logger = logging.getLogger(__name__)
@@ -76,6 +82,20 @@ def login() -> Any:
     """
     Login to FastAPI Cloud. 🚀
     """
+    token = get_auth_token()
+    if token is not None and is_token_expired(token):
+        with get_rich_toolkit(minimal=True) as toolkit:
+            toolkit.print("Your session has expired. Logging in again...")
+            toolkit.print_line()
+
+    if is_logged_in():
+        with get_rich_toolkit(minimal=True) as toolkit:
+            toolkit.print("You are already logged in.")
+            toolkit.print(
+                "Run [bold]fastapi logout[/bold] first if you want to switch accounts."
+            )
+        return
+
     with get_rich_toolkit() as toolkit, APIClient() as client:
         toolkit.print_title("Login to FastAPI Cloud", tag="FastAPI")
 
