@@ -1,3 +1,4 @@
+import time
 from pathlib import Path
 from unittest.mock import patch
 
@@ -9,6 +10,7 @@ from typer.testing import CliRunner
 
 from fastapi_cloud_cli.cli import app
 from fastapi_cloud_cli.config import Settings
+from tests.utils import create_jwt_token
 
 runner = CliRunner()
 settings = Settings.get()
@@ -162,3 +164,54 @@ def test_fetch_access_token_handles_500_error(respx_mock: respx.MockRouter) -> N
     with APIClient() as client:
         with pytest.raises(httpx.HTTPStatusError):
             _fetch_access_token(client, "test_device_code", 5)
+
+
+@pytest.mark.respx(base_url=settings.base_api_url)
+def test_notify_already_logged_in_user(
+    respx_mock: respx.MockRouter, logged_in_cli: None
+) -> None:
+    result = runner.invoke(app, ["login"])
+
+    assert result.exit_code == 0
+    assert "You are already logged in." in result.output
+    assert "Run fastapi logout first if you want to switch accounts." in result.output
+
+
+@pytest.mark.respx(base_url=settings.base_api_url)
+def test_notify_expired_token_user(
+    respx_mock: respx.MockRouter, temp_auth_config: Path
+) -> None:
+    past_exp = int(time.time()) - 3600
+    expired_token = create_jwt_token({"sub": "test_user_12345", "exp": past_exp})
+
+    temp_auth_config.write_text(f'{{"access_token": "{expired_token}"}}')
+
+    with patch("fastapi_cloud_cli.commands.login.typer.launch") as mock_open:
+        respx_mock.post(
+            "/login/device/authorization", data={"client_id": settings.client_id}
+        ).mock(
+            return_value=Response(
+                200,
+                json={
+                    "verification_uri_complete": "http://test.com",
+                    "verification_uri": "http://test.com",
+                    "user_code": "1234",
+                    "device_code": "5678",
+                },
+            )
+        )
+        respx_mock.post(
+            "/login/device/token",
+            data={
+                "device_code": "5678",
+                "client_id": settings.client_id,
+                "grant_type": "urn:ietf:params:oauth:grant-type:device_code",
+            },
+        ).mock(return_value=Response(200, json={"access_token": "new_token_1234"}))
+
+        result = runner.invoke(app, ["login"])
+
+        assert result.exit_code == 0
+        assert "Your session has expired. Logging in again..." in result.output
+        assert "Now you are logged in!" in result.output
+        assert mock_open.called
